@@ -196,18 +196,19 @@ names.or.rownames <- function(x){
 }
 
 mtable <- function(...,
-                    coef.style=getOption("coef.style"),
-                    summary.stats=TRUE,
-                    signif.symbols=getOption("signif.symbols"),
-                    factor.style=getOption("factor.style"),
-                    show.baselevel=getOption("show.baselevel"),
-                    baselevel.sep=getOption("baselevel.sep"),
-                    getSummary=eval.parent(quote(getSummary)),
-                    float.style=getOption("float.style"),
-                    digits=min(3,getOption("digits")),
-                    sdigits=digits,
-                    gs.options=NULL
-                    ){
+                   coef.style=getOption("coef.style"),
+                   summary.stats=TRUE,
+                   signif.symbols=getOption("signif.symbols"),
+                   factor.style=getOption("factor.style"),
+                   show.baselevel=getOption("show.baselevel"),
+                   baselevel.sep=getOption("baselevel.sep"),
+                   getSummary=eval.parent(quote(getSummary)),
+                   float.style=getOption("float.style"),
+                   digits=min(3,getOption("digits")),
+                   sdigits=digits,
+                   show.eqnames=getOption("mtable.show.eqnames",FALSE),
+                   gs.options=NULL
+                   ){
   args <- list(...)
   if(length(args)==1 && inherits(args[[1]],"by"))
     args <- args[[1]]
@@ -259,7 +260,8 @@ mtable <- function(...,
             float.style=float.style,
             digits=digits,
             stemplates=stemplates,
-            sdigits=sdigits
+            sdigits=sdigits,
+            show.eqnames=show.eqnames
             )
   
 }
@@ -474,6 +476,9 @@ preformat_mtable <- function(x){
     modelnames <- names(x)
     modelgroups <- attr(x,"model.groups")
 
+    force.header <- isTRUE(attr(x,"force.header")) # Document that later ...
+    show.eqnames <- attr(x,"show.eqnames")
+    
     parmtab <- NULL
     sect.headers <- NULL
     if(length(partypes)){
@@ -554,7 +559,9 @@ preformat_mtable <- function(x){
     
         for(m in rownames(sect.headers)){
             sh <- sect.headers[m,]
-            if(!getOption("mtable.always.eqnames",FALSE) && length(unique(unlist(sh)))==1){
+            if(is.na(show.eqnames))
+                show.eqnames <- (length(unique(unlist(sh))) > 1)
+            if(!show.eqnames ){
                 sh <- list(NULL)
             }
             sect.headers[m,] <- sh
@@ -562,7 +569,6 @@ preformat_mtable <- function(x){
     }
 
     headers <- list()
-    force.header <- getOption("mtable.force.header",default=FALSE)
     if(length(modelnames) > 1 || length(modelnames) == 1 && force.header) {
         modelnames <- do_subs(modelnames,relab.attr)
         headers[[1]] <- Map(structure,modelnames,span=lapply(parmtab[1,],ncol))
