@@ -123,7 +123,7 @@ SEXP countlines(SEXP s_file, SEXP s_maxlenline){
   return ScalarInteger(n);
 }
 
-SEXP readfixedchunk(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_cases, SEXP s_start, SEXP s_stop){
+SEXP readfixedslice(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_cases, SEXP s_start, SEXP s_stop){
   FILE *f = rofile_FILE(s_file);
   PROTECT(s_vars = coerceVector(s_vars,LGLSXP));
   PROTECT(s_cases = coerceVector(s_cases,LGLSXP));
@@ -170,7 +170,7 @@ SEXP readfixedchunk(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_cases, SEXP s_st
 #endif
     if(strlen(buffer)< max_lenline) {
       int new_length = i;
-      for(j = 0; j < nvar; j++){
+      for(j = 0; j < m; j++){
         x = VECTOR_ELT(data,j);
         SET_VECTOR_ELT(data,j,lengthgets(x,new_length));
       }
@@ -216,3 +216,94 @@ SEXP readfixedchunk(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_cases, SEXP s_st
   UNPROTECT(5);
   return data;
 }
+
+
+SEXP readfixedchunk(SEXP s_file, SEXP what, SEXP s_vars, SEXP s_nlines, SEXP s_start, SEXP s_stop){
+  PROTECT(s_vars = coerceVector(s_vars,LGLSXP));
+  PROTECT(s_start = coerceVector(s_start,INTSXP));
+  PROTECT(s_stop = coerceVector(s_stop,INTSXP));
+  FILE *f = rofile_FILE(s_file);
+  if(LENGTH(s_start) != LENGTH(s_stop)) error("start and stop must have equal length");
+	int m = 0;
+  int n = asInteger(s_nlines);
+  int nvar = LENGTH(what);
+  int i,j,k;
+  for(j = 0; j < LENGTH(s_vars); j++) m += LOGICAL(s_vars)[j];
+  int *start = INTEGER(s_start);
+  int *stop = INTEGER(s_stop);
+  int max_lenline = stop[nvar-1];
+  char *buffer = R_alloc(max_lenline+3,1);
+  char *item, *currdata;
+  SEXP data;
+  PROTECT(data=allocVector(VECSXP,m));
+  int *length = (int *) R_alloc(nvar,sizeof(int));
+  int maxlen = 0;
+  SEXP x,y;
+	k = 0;
+  for(j = 0; j < nvar; j++){
+    length[j] = stop[j] - start[j] + 1;
+    if(LOGICAL(s_vars)[j]){
+      if(maxlen < length[j]) maxlen = length[j];
+      x = VECTOR_ELT(what,j);
+      SET_VECTOR_ELT(data,k,lengthgets(x,n));
+      k++;
+    }
+  }
+  item = R_alloc(maxlen+1,1);
+#undef DEBUG
+#ifdef DEBUG
+  Rprintf("Requested number of lines: %d\n",n);
+#endif  
+  for(i = 0; i < n; i++){
+    memset(buffer,0,max_lenline+3);
+    buffer = fgets(buffer,max_lenline+3,f);
+#ifdef DEBUG
+    Rprintf("Requested line length: %d\n",max_lenline);
+    Rprintf("Actual line length: %d\n",strlen(buffer));
+    if(i == 0)
+      Rprintf("Buffer: >>%s<<\n",buffer);
+#endif    
+    if(strlen(buffer)< max_lenline) {
+      int new_length = i;
+      for(j = 0; j < m; j++){
+        x = VECTOR_ELT(data,j);
+        SET_VECTOR_ELT(data,j,lengthgets(x,new_length));
+      }
+      n = new_length;
+      break;
+    }
+    currdata = buffer;
+		k = 0;
+    for(j = 0; j < nvar; j++){
+        currdata = buffer + start[j]-1;
+        if(LOGICAL(s_vars)[j]){
+          x = VECTOR_ELT(data,k);
+          memset(item,0,maxlen+1);
+          memcpy(item,currdata,length[j]);
+          trim(item,length[j]);
+#ifdef DEBUG
+          Rprintf("Item: >>%s<<\n",item);
+#endif
+#undef DEBUG    
+          if(TYPEOF(x)==INTSXP)
+            INTEGER(x)[i] = _R_atoi(item);
+          else if (TYPEOF(x)==REALSXP)
+            REAL(x)[i] = _R_atof(item);
+          else
+            SET_STRING_ELT(x,i,mkChar(item));
+          k++;
+          }
+		}
+  }
+  k = 0;
+  for(j = 0; j < nvar; j++){
+    if(LOGICAL(s_vars)[j]){
+      x = VECTOR_ELT(what,j);
+      y = VECTOR_ELT(data,k);
+      copyMostAttrib(x,y);
+      k++;
+    }
+  }
+  UNPROTECT(4);
+  return data;
+}
